@@ -15,6 +15,8 @@ pub const DEFAULT_BYTE_LIMIT: usize = 1_000_000;
 // files (the highest is slow_before/after.rs at 1.3M nodes), but
 // small enough to terminate in ~5 seconds like the test file in #306.
 pub const DEFAULT_GRAPH_LIMIT: usize = 3_000_000;
+pub const DEFAULT_PARSE_ERROR_LIMIT: usize = 0;
+
 pub const DEFAULT_TAB_WIDTH: usize = 8;
 
 const USAGE: &str = concat!(env!("CARGO_BIN_NAME"), " [OPTIONS] OLD-PATH NEW-PATH");
@@ -59,7 +61,7 @@ impl Default for DisplayOptions {
 pub struct DiffOptions {
     pub graph_limit: usize,
     pub byte_limit: usize,
-    // pub error_limit: usize,
+    pub parse_error_limit: usize,
     pub check_only: bool,
     pub ignore_comments: bool,
 }
@@ -69,7 +71,7 @@ impl Default for DiffOptions {
         Self {
             graph_limit: DEFAULT_GRAPH_LIMIT,
             byte_limit: DEFAULT_BYTE_LIMIT,
-            // error_limit: 0,
+            parse_error_limit: DEFAULT_PARSE_ERROR_LIMIT,
             check_only: false,
             ignore_comments: false,
         }
@@ -184,7 +186,7 @@ fn app() -> clap::Command<'static> {
         .arg(
             Arg::new("check-only").long("check-only")
                 .env("DFT_CHECK_ONLY")
-                .help("Report whether there are any syntactic changes, but don't calculate them. Much faster.")
+                .help("Report whether there are any changes, but don't calculate them. Much faster.")
         )
         .arg(
             Arg::new("ignore-comments").long("ignore-comments")
@@ -214,7 +216,7 @@ fn app() -> clap::Command<'static> {
             Arg::new("byte-limit").long("byte-limit")
                 .takes_value(true)
                 .value_name("LIMIT")
-                .help(concat!("Use a text diff if either input file exceeds this size."))
+                .help("Use a text diff if either input file exceeds this size.")
                 .default_value(formatcp!("{}", DEFAULT_BYTE_LIMIT))
                 .env("DFT_BYTE_LIMIT")
                 .validator(|s| s.parse::<usize>())
@@ -224,22 +226,22 @@ fn app() -> clap::Command<'static> {
             Arg::new("graph-limit").long("graph-limit")
                 .takes_value(true)
                 .value_name("LIMIT")
-                .help(concat!("Use a text diff if the structural graph exceed this number of nodes in memory."))
+                .help("Use a text diff if the structural graph exceed this number of nodes in memory.")
                 .default_value(formatcp!("{}", DEFAULT_GRAPH_LIMIT))
                 .env("DFT_GRAPH_LIMIT")
                 .validator(|s| s.parse::<usize>())
                 .required(false),
         )
-        // .arg(
-        //     Arg::new("error-limit").long("error-limit")
-        //         .takes_value(true)
-        //         .value_name("LIMIT")
-        //         .help(concat!("Use a text diff if the number of parse errors exceeds this number."))
-        //         .default_value("0")
-        //         .env("DFT_ERROR_LIMIT")
-        //         .validator(|s| s.parse::<usize>())
-        //         .required(false),
-        // )
+        .arg(
+            Arg::new("parse-error-limit").long("parse-error-limit")
+                .takes_value(true)
+                .value_name("LIMIT")
+                .help("Use a text diff if the number of parse errors exceeds this value.")
+                .default_value(formatcp!("{}", DEFAULT_PARSE_ERROR_LIMIT))
+                .env("DFT_PARSE_ERROR_LIMIT")
+                .validator(|s| s.parse::<usize>())
+                .required(false),
+        )
         .arg(
             Arg::new("paths")
                 .value_name("PATHS")
@@ -490,11 +492,11 @@ pub fn parse_args() -> Mode {
         .parse::<usize>()
         .expect("Value already validated by clap");
 
-    // let error_limit = matches
-    //     .value_of("error-limit")
-    //     .expect("Always present as we've given clap a default")
-    //     .parse::<usize>()
-    //     .expect("Value already validated by clap");
+    let parse_error_limit = matches
+        .value_of("parse-error-limit")
+        .expect("Always present as we've given clap a default")
+        .parse::<usize>()
+        .expect("Value already validated by clap");
 
     let tab_width = matches
         .value_of("tab-width")
@@ -533,7 +535,7 @@ pub fn parse_args() -> Mode {
     let diff_options = DiffOptions {
         graph_limit,
         byte_limit,
-        // error_limit,
+        parse_error_limit,
         check_only,
         ignore_comments,
     };
