@@ -48,6 +48,7 @@ pub enum Language {
     Kotlin,
     Lua,
     Make,
+    Newick,
     Nix,
     OCaml,
     OCamlInterface,
@@ -57,6 +58,7 @@ pub enum Language {
     Python,
     Qml,
     R,
+    Racket,
     Ruby,
     Rust,
     Scala,
@@ -102,6 +104,7 @@ pub fn language_name(language: Language) -> &'static str {
         Kotlin => "Kotlin",
         Lua => "Lua",
         Make => "Make",
+        Newick => "Newick",
         Nix => "Nix",
         OCaml => "OCaml",
         OCamlInterface => "OCaml Interface",
@@ -111,6 +114,7 @@ pub fn language_name(language: Language) -> &'static str {
         Python => "Python",
         Qml => "QML",
         R => "R",
+        Racket => "Racket",
         Ruby => "Ruby",
         Rust => "Rust",
         Scala => "Scala",
@@ -195,6 +199,7 @@ pub const LANG_EXTENSIONS: &[(Language, &[&str])] = &[
     (Kotlin, &["kt", "ktm", "kts"]),
     (Lua, &["lua"]),
     (Make, &["mak", "d", "make", "makefile", "mk", "mkfile"]),
+    (Newick, &["nhx", "nwk", "nh"]),
     (Nix, &["nix"]),
     (OCaml, &["ml"]),
     (OCamlInterface, &["mli"]),
@@ -204,6 +209,7 @@ pub const LANG_EXTENSIONS: &[(Language, &[&str])] = &[
     (Python, &["py", "py3", "pyi", "bzl"]),
     (Qml, &["qml"]),
     (R, &["R", "r", "rd", "rsx"]),
+    (Racket, &["rkt"]),
     (Ruby, &["rb", "builder", "spec", "rake"]),
     (Rust, &["rs"]),
     (Scala, &["scala", "sbt", "sc"]),
@@ -364,6 +370,7 @@ fn from_emacs_mode_header(src: &str) -> Option<Language> {
             "lisp" => Some(CommonLisp),
             "perl" => Some(Perl),
             "python" => Some(Python),
+            "racket" => Some(Racket),
             "rjsx" => Some(Jsx),
             "ruby" => Some(Ruby),
             "rust" => Some(Rust),
