@@ -3,6 +3,7 @@
 use std::collections::HashMap;
 use std::collections::HashSet;
 
+use crate::options::DiffOptions;
 use crate::parse::guess_language as guess;
 use tree_sitter as ts;
 use typed_arena::Arena;
@@ -91,6 +92,7 @@ extern "C" {
     fn tree_sitter_kotlin() -> ts::Language;
     fn tree_sitter_lua() -> ts::Language;
     fn tree_sitter_make() -> ts::Language;
+    fn tree_sitter_newick() -> ts::Language;
     fn tree_sitter_nix() -> ts::Language;
     fn tree_sitter_ocaml() -> ts::Language;
     fn tree_sitter_ocaml_interface() -> ts::Language;
@@ -100,6 +102,7 @@ extern "C" {
     fn tree_sitter_python() -> ts::Language;
     fn tree_sitter_qmljs() -> ts::Language;
     fn tree_sitter_r() -> ts::Language;
+    fn tree_sitter_racket() -> ts::Language;
     fn tree_sitter_ruby() -> ts::Language;
     fn tree_sitter_rust() -> ts::Language;
     fn tree_sitter_scala() -> ts::Language;
@@ -619,6 +622,20 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 }],
             }
         }
+        Newick => {
+            let language = unsafe { tree_sitter_newick() };
+            TreeSitterConfig {
+                language,
+                atom_nodes: vec![].into_iter().collect(),
+                delimiter_tokens: vec![("(", ")")],
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../../vendored_parsers/highlights/newick.scm"),
+                )
+                .unwrap(),
+                sub_languages: vec![],
+            }
+        }
         Nix => {
             let language = unsafe { tree_sitter_nix() };
             TreeSitterConfig {
@@ -764,6 +781,22 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
                 sub_languages: vec![],
             }
         }
+        Racket => {
+            let language = unsafe { tree_sitter_racket() };
+            TreeSitterConfig {
+                language,
+                atom_nodes: vec!["string", "byte_string", "regex", "here_string"]
+                    .into_iter()
+                    .collect(),
+                delimiter_tokens: vec![("{", "}"), ("(", ")"), ("[", "]")],
+                highlight_query: ts::Query::new(
+                    language,
+                    include_str!("../../vendored_parsers/highlights/racket.scm"),
+                )
+                .unwrap(),
+                sub_languages: vec![],
+            }
+        }
         Ruby => {
             let language = unsafe { tree_sitter_ruby() };
             TreeSitterConfig {
@@ -946,6 +979,23 @@ pub fn to_tree(src: &str, config: &TreeSitterConfig) -> tree_sitter::Tree {
     parser.parse(src, None).unwrap()
 }
 
+#[derive(Debug)]
+pub struct ExceededByteLimit(pub usize);
+
+pub fn to_tree_with_limit(
+    diff_options: &DiffOptions,
+    config: &TreeSitterConfig,
+    lhs_src: &str,
+    rhs_src: &str,
+) -> Result<(tree_sitter::Tree, tree_sitter::Tree), ExceededByteLimit> {
+    if lhs_src.len() > diff_options.byte_limit || rhs_src.len() > diff_options.byte_limit {
+        let num_bytes = std::cmp::max(lhs_src.len(), rhs_src.len());
+        return Err(ExceededByteLimit(num_bytes));
+    }
+
+    Ok((to_tree(lhs_src, config), to_tree(rhs_src, config)))
+}
+
 /// Find any nodes that can be parsed as other languages (e.g. JavaScript embedded in HTML),
 /// and return a map of their node IDs mapped to parsed trees. Every time we see such a node,
 /// we will ignore it and recurse into the root node of the given tree instead.
@@ -1020,6 +1070,8 @@ fn tree_highlights(
             || name == "repeat"
             || name == "conditional"
             || name == "boolean"
+            || name == "exception"
+            || name == "include"
         {
             keyword_ish_capture_ids.push(idx as u32);
         }
@@ -1115,7 +1167,7 @@ pub fn comment_positions(
     let arena = Arena::new();
     let ignore_comments = false;
 
-    let nodes = to_syntax(tree, src, &arena, config, ignore_comments);
+    let (nodes, _err_count) = to_syntax(tree, src, &arena, config, ignore_comments);
     let positions = syntax::comment_positions(&nodes);
 
     positions
@@ -1129,18 +1181,54 @@ pub fn comment_positions(
         .collect()
 }
 
+#[derive(Debug)]
+pub struct ExceededParseErrorLimit(pub usize);
+
+pub fn to_syntax_with_limit<'a>(
+    lhs_src: &str,
+    rhs_src: &str,
+    lhs_tree: &tree_sitter::Tree,
+    rhs_tree: &tree_sitter::Tree,
+    arena: &'a Arena<Syntax<'a>>,
+    config: &TreeSitterConfig,
+    diff_options: &DiffOptions,
+) -> Result<(Vec<&'a Syntax<'a>>, Vec<&'a Syntax<'a>>), ExceededParseErrorLimit> {
+    let (lhs_nodes, lhs_error_count) = to_syntax(
+        lhs_tree,
+        lhs_src,
+        arena,
+        config,
+        diff_options.ignore_comments,
+    );
+    let (rhs_nodes, rhs_error_count) = to_syntax(
+        rhs_tree,
+        rhs_src,
+        arena,
+        config,
+        diff_options.ignore_comments,
+    );
+    syntax::init_all_info(&lhs_nodes, &rhs_nodes);
+
+    let error_count = lhs_error_count + rhs_error_count;
+    if error_count > diff_options.parse_error_limit {
+        return Err(ExceededParseErrorLimit(error_count));
+    }
+
+    Ok((lhs_nodes, rhs_nodes))
+}
+
 pub fn to_syntax<'a>(
     tree: &tree_sitter::Tree,
     src: &str,
     arena: &'a Arena<Syntax<'a>>,
     config: &TreeSitterConfig,
     ignore_comments: bool,
-) -> Vec<&'a Syntax<'a>> {
+) -> (Vec<&'a Syntax<'a>>, usize) {
     // Don't return anything on an empty input. Most parsers return a
     // zero-width top-level AST node on empty files, which is
     // confusing and not useful for diffing.
     if src.trim().is_empty() {
-        return vec![];
+        return (vec![], 0);
     }
 
     let highlights = tree_highlights(tree, src, config);
@@ -1156,16 +1244,19 @@ pub fn to_syntax<'a>(
     // each top level syntax item.
     cursor.goto_first_child();
 
-    all_syntaxes_from_cursor(
+    let mut error_count: usize = 0;
+    let nodes = all_syntaxes_from_cursor(
         arena,
         src,
         &nl_pos,
         &mut cursor,
+        &mut error_count,
         config,
         &highlights,
         &subtrees,
         ignore_comments,
-    )
+    );
+    (nodes, error_count)
 }
 
 /// Parse `src` with tree-sitter and convert to difftastic Syntax.
@@ -1176,7 +1267,8 @@ pub fn parse<'a>(
     ignore_comments: bool,
 ) -> Vec<&'a Syntax<'a>> {
     let tree = to_tree(src, config);
-    to_syntax(&tree, src, arena, config, ignore_comments)
+    let (nodes, _err_count) = to_syntax(&tree, src, arena, config, ignore_comments);
+    nodes
 }
 
 fn child_tokens<'a>(src: &'a str, cursor: &mut ts::TreeCursor) -> Vec<Option<&'a str>> {
@@ -1243,6 +1335,7 @@ fn all_syntaxes_from_cursor<'a>(
     src: &str,
     nl_pos: &NewlinePositions,
     cursor: &mut ts::TreeCursor,
+    error_count: &mut usize,
     config: &TreeSitterConfig,
     highlights: &HighlightedNodeIds,
     subtrees: &HashMap<usize, (tree_sitter::Tree, TreeSitterConfig, HighlightedNodeIds)>,
@@ -1256,6 +1349,7 @@ fn all_syntaxes_from_cursor<'a>(
             src,
             nl_pos,
             cursor,
+            error_count,
             config,
             highlights,
             subtrees,
@@ -1277,6 +1371,7 @@ fn syntax_from_cursor<'a>(
     src: &str,
     nl_pos: &NewlinePositions,
     cursor: &mut ts::TreeCursor,
+    error_count: &mut usize,
     config: &TreeSitterConfig,
     highlights: &HighlightedNodeIds,
     subtrees: &HashMap<usize, (tree_sitter::Tree, TreeSitterConfig, HighlightedNodeIds)>,
@@ -1292,6 +1387,7 @@ fn syntax_from_cursor<'a>(
             src,
             nl_pos,
             &mut sub_cursor,
+            error_count,
             subconfig,
             subhighlights,
             &HashMap::new(),
@@ -1300,13 +1396,7 @@ fn syntax_from_cursor<'a>(
     }
 
     if node.is_error() {
-        let position = nl_pos.from_offsets(node.start_byte(), node.end_byte());
-        let content = &src[node.start_byte()..node.end_byte()];
-        debug!(
-            "Tree-sitter syntax error at {:?}: {}",
-            position.get(0),
-            content
-        );
+        *error_count += 1;
 
         // Treat error nodes as atoms, even if they have children.
         atom_from_cursor(arena, src, nl_pos, cursor, highlights, ignore_comments)
@@ -1320,6 +1410,7 @@ fn syntax_from_cursor<'a>(
             src,
             nl_pos,
             cursor,
+            error_count,
             config,
             highlights,
             subtrees,
@@ -1337,6 +1428,7 @@ fn list_from_cursor<'a>(
     src: &str,
     nl_pos: &NewlinePositions,
     cursor: &mut ts::TreeCursor,
+    error_count: &mut usize,
     config: &TreeSitterConfig,
     highlights: &HighlightedNodeIds,
     subtrees: &HashMap<usize, (tree_sitter::Tree, TreeSitterConfig, HighlightedNodeIds)>,
@@ -1388,6 +1480,7 @@ fn list_from_cursor<'a>(
                 src,
                 nl_pos,
                 cursor,
+                error_count,
                 config,
                 highlights,
                 subtrees,
@@ -1402,6 +1495,7 @@ fn list_from_cursor<'a>(
                 src,
                 nl_pos,
                 cursor,
+                error_count,
                 config,
                 highlights,
                 subtrees,
@@ -1416,6 +1510,7 @@ fn list_from_cursor<'a>(
                 src,
                 nl_pos,
                 cursor,
+                error_count,
                 config,
                 highlights,
                 subtrees,
